pub struct runtime {}Expand description
An extension for use with the Deno JS runtime. To use it, provide it as an argument when instantiating your runtime:
ⓘ
use deno_core::{ JsRuntime, RuntimeOptions };
let mut extensions = vec![runtime::init()];
let mut js_runtime = JsRuntime::new(RuntimeOptions {
extensions,
..Default::default()
});Implementations
Sourceimpl runtime
impl runtime
Sourcepub fn init() -> Extension
pub fn init() -> Extension
Initialize this extension for runtime or snapshot creation.
Returns
an Extension object that can be used during instantiation of a JsRuntime
Sourcepub fn lazy_init() -> Extension
pub fn lazy_init() -> Extension
Initialize this extension for runtime or snapshot creation.
If this method is used, you must later call JsRuntime::lazy_init_extensions
with the result of this extension’s args method.
Returns
an Extension object that can be used during instantiation of a JsRuntime
Sourcepub fn args() -> ExtensionArguments
pub fn args() -> ExtensionArguments
Create an ExtensionArguments value which must be passed to
JsRuntime::lazy_init_extensions.